pub enum AnthropicStopReason {
EndTurn,
MaxTokens,
StopSequence,
ToolUse,
PauseTurn,
Refusal,
}Expand description
Reason the model stopped generating.
Variants
EndTurn
MaxTokens
StopSequence
ToolUse
PauseTurn
The model paused to yield control in an agentic loop, intending to continue in a subsequent turn. Used with extended thinking / tool use.
Refusal
The model refused to generate content (safety refusal).