pub struct AnthropicToolChoiceSimple {
pub choice_type: AnthropicToolChoiceMode,
pub disable_parallel_tool_use: Option<bool>,
}Expand description
Simple tool choice modes.
Fields
choice_type: AnthropicToolChoiceModedisable_parallel_tool_use: Option<bool>When true, the model will call tools one at a time instead of potentially issuing multiple tool calls in a single response.