pub struct AnthropicUsage {
pub input_tokens: u32,
pub output_tokens: u32,
pub cache_creation_input_tokens: Option<u32>,
pub cache_read_input_tokens: Option<u32>,
}Expand description
Token usage information.
Fields
input_tokens: u32output_tokens: u32cache_creation_input_tokens: Option<u32>Number of input tokens used to create a new cache entry.
cache_read_input_tokens: Option<u32>Number of input tokens read from the prompt cache (prefix cache hits).