pub struct AssistantMessageContentOutputAudio {
pub audio: Option<String>,
pub transcript: String,
}Fields
audio: Option<String>Base64-encoded audio bytes, these will be parsed as the format specified in the session output audio type configuration. This defaults to PCM 16-bit 24kHz mono if not specified.
transcript: StringThe transcript of the audio content, this will always be present if the
output type is audio.