pub struct AudioOutput {
pub format: RealtimeAudioFormats,
pub speed: f32,
pub voice: RealtimeVoice,
}Fields
format: RealtimeAudioFormatsThe format of the output audio.
speed: f32The speed of the model’s spoken response as a multiple of the original speed. 1.0 is the default speed. 0.25 is the minimum speed. 1.5 is the maximum speed. This value can only be changed in between model turns, not while a response is in progress.
This parameter is a post-processing adjustment to the audio after it is generated, it’s also possible to prompt the model to speak faster or slower.
voice: RealtimeVoiceThe voice the model uses to respond. Supported built-in voices are alloy, ash, ballad,
coral, echo, sage, shimmer, verse, marin, and cedar. Voice cannot be changed during
the session once the model has responded with audio at least once. We recommend marin and cedar
for best quality.