pub struct AudioTranscription {
pub language: Option<String>,
pub model: Option<String>,
pub prompt: Option<String>,
pub delay: Option<AudioTranscriptionDelay>,
}Fields
language: Option<String>The language of the input audio. Supplying the input language in
ISO-639-1 (e.g. en) format will improve accuracy and latency.
model: Option<String>The model to use for transcription. Current options are whisper-1,
gpt-4o-mini-transcribe, gpt-4o-mini-transcribe-2025-12-15, gpt-4o-transcribe,
gpt-4o-transcribe-diarize, and gpt-realtime-whisper.
Use gpt-4o-transcribe-diarize when you need diarization with speaker labels.
prompt: Option<String>An optional text to guide the model’s style or continue a previous audio segment.
For whisper-1, the prompt is a list of keywords. For gpt-4o-transcribe models
(excluding gpt-4o-transcribe-diarize), the prompt is a free text string, for example
“expect words related to technology”.
Prompt is not supported with gpt-realtime-whisper in GA Realtime sessions.
delay: Option<AudioTranscriptionDelay>Controls how long the model waits before emitting transcription text.
Higher values can improve transcription accuracy at the cost of latency.
Only supported with gpt-realtime-whisper in GA Realtime sessions.