pub struct AudioTranscriptionResponse {
pub language: Option<String>,
pub model: Option<String>,
pub prompt: Option<String>,
}Expand description
Configuration of the transcription model returned by the server.
Fields
language: Option<String>The language of the input audio.
model: Option<String>The model used for transcription.
prompt: Option<String>The prompt configured for input audio transcription, when present.