pub struct RealtimeConversationItemFunctionCallOutput {
pub call_id: String,
pub output: String,
pub id: Option<String>,
pub object: Option<String>,
pub status: String,
}Fields
call_id: StringThe ID of the function call this output is for.
output: StringThe output of the function call, this is free text and can contain any information or simply be empty.
id: Option<String>The unique ID of the item. This may be provided by the client or generated by the server.
object: Option<String>Identifier for the API object being returned - always realtime.item.
Optional when creating a new item.
status: StringThe status of the item. Has no effect on the conversation.