pub struct RealtimeServerEventInputAudioBufferSpeechStopped {
pub event_id: String,
pub audio_end_ms: u32,
pub item_id: String,
}Fields
event_id: StringThe unique ID of the server event.
audio_end_ms: u32Milliseconds since the session started when speech stopped. This will correspond to the end of
audio sent to the model, and thus includes the min_silence_duration_ms configured in the Session.
item_id: StringThe ID of the user message item that will be created.