pub struct RealtimeServerEventResponseAudioTranscriptDone {
pub event_id: String,
pub response_id: String,
pub item_id: String,
pub output_index: u32,
pub content_index: u32,
pub transcript: String,
}Fields
event_id: StringThe unique ID of the server event.
response_id: StringThe ID of the response.
item_id: StringThe ID of the item.
output_index: u32The index of the output item in the response.
content_index: u32The index of the content part in the item’s content array.
transcript: StringThe final transcript of the audio.