pub struct RealtimeServerEventResponseOutputItemDone {
pub event_id: String,
pub response_id: String,
pub output_index: u32,
pub item: RealtimeConversationItem,
}Fields
event_id: StringThe unique ID of the server event.
response_id: StringThe ID of the response to which the item belongs.
output_index: u32The index of the output item in the Response.
item: RealtimeConversationItemA single item within a Realtime conversation.