pub struct RealtimeTranslationClientSecretCreateResponse {
pub value: String,
pub expires_at: u64,
pub session: RealtimeTranslationSession,
}Expand description
Response from creating a translation session and client secret for the Realtime API.
Fields
value: StringThe generated client secret value.
expires_at: u64Expiration timestamp for the client secret, in seconds since epoch.
session: RealtimeTranslationSessionThe translation session.