pub struct RealtimeTranslationClientSecretExpiresAfter {
pub anchor: Option<RealtimeTranslationClientSecretExpiresAnchor>,
pub seconds: Option<u32>,
}Expand description
Configuration for the client secret expiration. Expiration refers to the time after which a client secret will no longer be valid for creating sessions. The session itself may continue after that time once started. A secret can be used to create multiple sessions until it expires.
Fields
anchor: Option<RealtimeTranslationClientSecretExpiresAnchor>The anchor point for the client secret expiration, meaning that
seconds will be added to the created_at time of the client
secret to produce an expiration timestamp. Only created_at is currently supported.
seconds: Option<u32>The number of seconds from the anchor point to the expiration. Select a value between
10 and 7200 (2 hours). Defaults to 600 seconds (10 minutes) if not specified.