pub enum CustomToolCallOutputOutput {
Text(String),
List(Vec<InputContent>),
}Variants
Text(String)
A string of the output of the custom tool call.
List(Vec<InputContent>)
Text, image, or file output of the custom tool call.