pub struct ApplyPatchDeleteFileOperationParam {
pub path: String,
}Expand description
Instruction for deleting an existing file via the apply_patch tool.
Fields
path: StringPath of the file to delete relative to the workspace root.