pub struct ApplyPatchToolCallOutputItemParam {
pub id: Option<String>,
pub call_id: String,
pub status: ApplyPatchCallOutputStatusParam,
pub output: Option<String>,
}Expand description
The streamed output emitted by an apply patch tool call.
Fields
id: Option<String>The unique ID of the apply patch tool call output. Populated when this item is returned via API.
call_id: StringThe unique ID of the apply patch tool call generated by the model.
status: ApplyPatchCallOutputStatusParamThe status of the apply patch tool call output. One of completed or failed.
output: Option<String>Optional human-readable log text from the apply patch tool (e.g., patch results or errors).