pub struct ApplyPatchUpdateFileOperationParam {
pub path: String,
pub diff: String,
}Expand description
Instruction for updating an existing file via the apply_patch tool.
Fields
path: StringPath of the file to update relative to the workspace root.
diff: StringUnified diff content to apply to the existing file.