pub struct CustomToolCallOutputResource {
pub call_id: String,
pub output: CustomToolCallOutputOutput,
pub id: String,
pub status: FunctionCallOutputStatusEnum,
pub created_by: Option<String>,
}Expand description
A custom tool call output item returned by the API.
Fields
call_id: StringThe call ID, used to map this custom tool call output to a custom tool call.
output: CustomToolCallOutputOutputThe output from the custom tool call generated by your code. Can be a string or a list of output content.
id: StringThe unique ID of the custom tool call output item.
status: FunctionCallOutputStatusEnumThe status of the item. One of in_progress, completed, or incomplete.
created_by: Option<String>The identifier of the actor that created the item.