pub struct CustomToolParam {
pub name: String,
pub description: Option<String>,
pub format: CustomToolParamFormat,
pub defer_loading: Option<bool>,
}Fields
name: StringThe name of the custom tool, used to identify it in tool calls.
description: Option<String>Optional description of the custom tool, used to provide more context.
format: CustomToolParamFormatThe input format for the custom tool. Default is unconstrained text.
defer_loading: Option<bool>Whether this tool should be deferred and discovered via tool search.