pub struct FunctionCallOutputItemParam {
pub call_id: String,
pub output: FunctionCallOutput,
pub id: Option<String>,
pub status: Option<OutputStatus>,
}Expand description
Output from a function call that you’re providing back to the model.
Fields
call_id: StringThe unique ID of the function tool call generated by the model.
output: FunctionCallOutputText, image, or file output of the function tool call.
id: Option<String>The unique ID of the function tool call output. Populated when this item is returned via API.
status: Option<OutputStatus>The status of the item. One of in_progress, completed, or incomplete.
Populated when items are returned via API.