pub struct FunctionShellCallOutputContentParam {
pub stdout: String,
pub stderr: String,
pub outcome: FunctionShellCallOutputOutcomeParam,
}Expand description
Captured stdout and stderr for a portion of a shell tool call output.
Fields
stdout: StringCaptured stdout output for this chunk of the shell call.
stderr: StringCaptured stderr output for this chunk of the shell call.
outcome: FunctionShellCallOutputOutcomeParamThe exit or timeout outcome associated with this chunk.