pub struct FunctionToolArgs { /* private fields */ }Expand description
Builder for FunctionTool.
Implementations
Sourceimpl FunctionToolArgs
impl FunctionToolArgs
Sourcepub fn name<VALUE>(&mut self, value: VALUE) -> &mut FunctionToolArgs
pub fn name<VALUE>(&mut self, value: VALUE) -> &mut FunctionToolArgs
The name of the function to call.
Sourcepub fn parameters<VALUE>(&mut self, value: VALUE) -> &mut FunctionToolArgs
pub fn parameters<VALUE>(&mut self, value: VALUE) -> &mut FunctionToolArgs
A JSON schema object describing the parameters of the function.
Sourcepub fn strict<VALUE>(&mut self, value: VALUE) -> &mut FunctionToolArgs
pub fn strict<VALUE>(&mut self, value: VALUE) -> &mut FunctionToolArgs
Whether to enforce strict parameter validation. Default true.
Sourcepub fn description<VALUE>(&mut self, value: VALUE) -> &mut FunctionToolArgs
pub fn description<VALUE>(&mut self, value: VALUE) -> &mut FunctionToolArgs
A description of the function. Used by the model to determine whether or not to call the function.
Sourcepub fn defer_loading<VALUE>(&mut self, value: VALUE) -> &mut FunctionToolArgs
pub fn defer_loading<VALUE>(&mut self, value: VALUE) -> &mut FunctionToolArgs
Whether this function is deferred and loaded via tool search.
Sourcepub fn build(&self) -> Result<FunctionTool, FunctionToolArgsError>
pub fn build(&self) -> Result<FunctionTool, FunctionToolArgsError>