pub struct GetResponseQueryArgs { /* private fields */ }Expand description
Builder for GetResponseQuery.
Implementations
Sourceimpl GetResponseQueryArgs
impl GetResponseQueryArgs
Sourcepub fn include<VALUE>(&mut self, value: VALUE) -> &mut GetResponseQueryArgs
pub fn include<VALUE>(&mut self, value: VALUE) -> &mut GetResponseQueryArgs
Additional fields to include in the response.
Sourcepub fn stream<VALUE>(&mut self, value: VALUE) -> &mut GetResponseQueryArgs
pub fn stream<VALUE>(&mut self, value: VALUE) -> &mut GetResponseQueryArgs
If set to true, the model response data will be streamed to the client as it is generated using server-sent events.
Sourcepub fn starting_after<VALUE>(
&mut self,
value: VALUE,
) -> &mut GetResponseQueryArgs
pub fn starting_after<VALUE>( &mut self, value: VALUE, ) -> &mut GetResponseQueryArgs
The sequence number of the event after which to start streaming.
Sourcepub fn include_obfuscation<VALUE>(
&mut self,
value: VALUE,
) -> &mut GetResponseQueryArgs
pub fn include_obfuscation<VALUE>( &mut self, value: VALUE, ) -> &mut GetResponseQueryArgs
When true, stream obfuscation will be enabled.
Sourcepub fn build(&self) -> Result<GetResponseQuery, OpenAIError>
pub fn build(&self) -> Result<GetResponseQuery, OpenAIError>