pub struct InputImageArgs { /* private fields */ }Expand description
Builder for InputImageContent.
Implementations
Sourceimpl InputImageArgs
impl InputImageArgs
Sourcepub fn detail<VALUE>(&mut self, value: VALUE) -> &mut InputImageArgswhere
VALUE: Into<ImageDetail>,
pub fn detail<VALUE>(&mut self, value: VALUE) -> &mut InputImageArgswhere
VALUE: Into<ImageDetail>,
The detail level of the image to be sent to the model. One of high, low, or auto.
Defaults to auto.
Sourcepub fn file_id<VALUE>(&mut self, value: VALUE) -> &mut InputImageArgs
pub fn file_id<VALUE>(&mut self, value: VALUE) -> &mut InputImageArgs
The ID of the file to be sent to the model.
Sourcepub fn image_url<VALUE>(&mut self, value: VALUE) -> &mut InputImageArgs
pub fn image_url<VALUE>(&mut self, value: VALUE) -> &mut InputImageArgs
The URL of the image to be sent to the model. A fully qualified URL or base64 encoded image in a data URL.
Sourcepub fn build(&self) -> Result<InputImageContent, OpenAIError>
pub fn build(&self) -> Result<InputImageContent, OpenAIError>