pub struct ReasoningArgs { /* private fields */ }Expand description
Builder for Reasoning.
Implementations
Sourceimpl ReasoningArgs
impl ReasoningArgs
Sourcepub fn effort<VALUE>(&mut self, value: VALUE) -> &mut ReasoningArgswhere
VALUE: Into<ReasoningEffort>,
pub fn effort<VALUE>(&mut self, value: VALUE) -> &mut ReasoningArgswhere
VALUE: Into<ReasoningEffort>,
Constrains effort on reasoning for
reasoning models.
Currently supported values are minimal, low, medium, and high. Reducing
reasoning effort can result in faster responses and fewer tokens used
on reasoning in a response.
Note: The gpt-5-pro model defaults to (and only supports) high reasoning effort.
Sourcepub fn summary<VALUE>(&mut self, value: VALUE) -> &mut ReasoningArgswhere
VALUE: Into<ReasoningSummary>,
pub fn summary<VALUE>(&mut self, value: VALUE) -> &mut ReasoningArgswhere
VALUE: Into<ReasoningSummary>,
A summary of the reasoning performed by the model. This can be
useful for debugging and understanding the model’s reasoning process.
One of auto, concise, or detailed.
concise is supported for computer-use-preview models and all reasoning models after
gpt-5.