pub struct ResponseShellCallCommandAddedStreamingEvent {
pub sequence_number: u64,
pub output_index: u32,
pub command_index: u32,
pub command: String,
}Expand description
A streaming event that indicated a shell command was added to a tool call.
Fields
sequence_number: u64The sequence number of the event that was emitted.
output_index: u32The index of the output item that was updated.
command_index: u32The index of the shell command that was added.
command: StringThe shell command that was added.