pub struct ResponseShellCallOutputContentDeltaStreamingEvent {
pub sequence_number: u64,
pub item_id: String,
pub output_index: u32,
pub command_index: u32,
pub delta: ShellCallOutputDelta,
}Expand description
A streaming event that indicated shell call output was incrementally added.
Fields
sequence_number: u64The sequence number of the event that was emitted.
item_id: StringThe ID of the output item that was updated.
output_index: u32The index of the output item that was updated.
command_index: u32The index of the shell command that produced output.
delta: ShellCallOutputDeltaThe stdout/stderr delta that was emitted.