ResponseTextParam

Struct ResponseTextParam 

pub struct ResponseTextParam {
    pub format: TextResponseFormatConfiguration,
    pub verbosity: Option<Verbosity>,
}
Configuration for text response format.

Fields

format: TextResponseFormatConfiguration

An object specifying the format that the model must output.

Configuring { "type": "json_schema" } enables Structured Outputs, which ensures the model will match your supplied JSON schema. Learn more in the Structured Outputs guide.

The default format is { "type": "text" } with no additional options.

Not recommended for gpt-4o and newer models:

Setting to { "type": "json_object" } enables the older JSON mode, which ensures the message the model generates is valid JSON. Using json_schema is preferred for models that support it.

verbosity: Option<Verbosity>

Constrains the verbosity of the model’s response. Lower values will result in more concise responses, while higher values will result in more verbose responses.

Currently supported values are low, medium, and high.