TokenCountsBodyArgs

Struct TokenCountsBodyArgs 

pub struct TokenCountsBodyArgs { /* private fields */ }
Builder for TokenCountsBody.

Implementations

Source

impl TokenCountsBodyArgs

pub fn conversation<VALUE>(&mut self, value: VALUE) -> &mut TokenCountsBodyArgs
where VALUE: Into<ConversationParam>,

The conversation that this response belongs to. Items from this conversation are prepended to input_items for this response request. Input items and output items from this response are automatically added to this conversation after this response completes.

pub fn input<VALUE>(&mut self, value: VALUE) -> &mut TokenCountsBodyArgs
where VALUE: Into<InputParam>,

Text, image, or file inputs to the model, used to generate a response

pub fn instructions<VALUE>(&mut self, value: VALUE) -> &mut TokenCountsBodyArgs
where VALUE: Into<String>,

A system (or developer) message inserted into the model’s context.

When used along with previous_response_id, the instructions from a previous response will not be carried over to the next response. This makes it simple to swap out system (or developer) messages in new responses.

pub fn model<VALUE>(&mut self, value: VALUE) -> &mut TokenCountsBodyArgs
where VALUE: Into<String>,

Model ID used to generate the response, like gpt-4o or o3. OpenAI offers a wide range of models with different capabilities, performance characteristics, and price points. Refer to the model guide to browse and compare available models.

pub fn parallel_tool_calls<VALUE>( &mut self, value: VALUE, ) -> &mut TokenCountsBodyArgs
where VALUE: Into<bool>,

Whether to allow the model to run tool calls in parallel.

pub fn previous_response_id<VALUE>( &mut self, value: VALUE, ) -> &mut TokenCountsBodyArgs
where VALUE: Into<String>,

The unique ID of the previous response to the model. Use this to create multi-turn conversations. Learn more about conversation state. Cannot be used in conjunction with conversation.

pub fn reasoning<VALUE>(&mut self, value: VALUE) -> &mut TokenCountsBodyArgs
where VALUE: Into<Reasoning>,

gpt-5 and o-series models only Configuration options for reasoning models.

pub fn text<VALUE>(&mut self, value: VALUE) -> &mut TokenCountsBodyArgs
where VALUE: Into<ResponseTextParam>,

Configuration options for a text response from the model. Can be plain text or structured JSON data. Learn more:

pub fn tool_choice<VALUE>(&mut self, value: VALUE) -> &mut TokenCountsBodyArgs
where VALUE: Into<ToolChoiceParam>,

How the model should select which tool (or tools) to use when generating a response. See the tools parameter to see how to specify which tools the model can call.

pub fn tools<VALUE>(&mut self, value: VALUE) -> &mut TokenCountsBodyArgs
where VALUE: Into<Vec<Tool>>,

An array of tools the model may call while generating a response. You can specify which tool to use by setting the tool_choice parameter.

pub fn truncation<VALUE>(&mut self, value: VALUE) -> &mut TokenCountsBodyArgs
where VALUE: Into<Truncation>,

The truncation strategy to use for the model response.

  • auto: If the input to this Response exceeds the model’s context window size, the model will truncate the response to fit the context window by dropping items from the beginning of the conversation.
  • disabled (default): If the input size will exceed the context window size for a model, the request will fail with a 400 error.
pub fn build(&self) -> Result<TokenCountsBody, OpenAIError>

Builds a new TokenCountsBody.

Errors

If a required field has not been initialized.