pub struct ToolSearchOutputItemParam {
pub id: Option<String>,
pub call_id: Option<String>,
pub execution: Option<ToolSearchExecutionType>,
pub tools: Vec<Tool>,
pub status: Option<OutputStatus>,
}Expand description
A tool search output input item.
Fields
id: Option<String>The unique ID of this tool search output.
call_id: Option<String>The unique ID of the tool search call generated by the model.
execution: Option<ToolSearchExecutionType>Whether tool search was executed by the server or by the client.
tools: Vec<Tool>The loaded tool definitions returned by the tool search output.
status: Option<OutputStatus>The status of the tool search output.