pub struct WebSearchApproximateLocationArgs { /* private fields */ }Expand description
Builder for WebSearchApproximateLocation.
Implementations
Sourceimpl WebSearchApproximateLocationArgs
impl WebSearchApproximateLocationArgs
Sourcepub fn type<VALUE>(
&mut self,
value: VALUE,
) -> &mut WebSearchApproximateLocationArgswhere
VALUE: Into<WebSearchApproximateLocationType>,
pub fn type<VALUE>(
&mut self,
value: VALUE,
) -> &mut WebSearchApproximateLocationArgswhere
VALUE: Into<WebSearchApproximateLocationType>,
The type of location approximation. Defaults to approximate when omitted in JSON input.
Sourcepub fn city<VALUE>(
&mut self,
value: VALUE,
) -> &mut WebSearchApproximateLocationArgs
pub fn city<VALUE>( &mut self, value: VALUE, ) -> &mut WebSearchApproximateLocationArgs
Free text input for the city of the user, e.g. San Francisco.
Sourcepub fn country<VALUE>(
&mut self,
value: VALUE,
) -> &mut WebSearchApproximateLocationArgs
pub fn country<VALUE>( &mut self, value: VALUE, ) -> &mut WebSearchApproximateLocationArgs
The two-letter ISO country code of the user,
e.g. US.
Sourcepub fn region<VALUE>(
&mut self,
value: VALUE,
) -> &mut WebSearchApproximateLocationArgs
pub fn region<VALUE>( &mut self, value: VALUE, ) -> &mut WebSearchApproximateLocationArgs
Free text input for the region of the user, e.g. California.
Sourcepub fn timezone<VALUE>(
&mut self,
value: VALUE,
) -> &mut WebSearchApproximateLocationArgs
pub fn timezone<VALUE>( &mut self, value: VALUE, ) -> &mut WebSearchApproximateLocationArgs
The IANA timezone of the user, e.g.
America/Los_Angeles.
Sourcepub fn build(&self) -> Result<WebSearchApproximateLocation, OpenAIError>
pub fn build(&self) -> Result<WebSearchApproximateLocation, OpenAIError>