pub type PromptConfig = Prompt;Aliased Type
pub struct PromptConfig {
pub id: String,
pub version: Option<String>,
pub variables: Option<ResponsePromptVariables>,
}Fields
id: StringThe unique identifier of the prompt template to use.
version: Option<String>Optional version of the prompt template.
variables: Option<ResponsePromptVariables>Optional map of values to substitute in for variables in your prompt. The substitution values can either be strings, or other Response input types like images or files.