pub struct CreateEmbeddingRequestArgs { /* private fields */ }Expand description
Builder for CreateEmbeddingRequest.
Implementations
Sourceimpl CreateEmbeddingRequestArgs
impl CreateEmbeddingRequestArgs
Sourcepub fn model<VALUE>(&mut self, value: VALUE) -> &mut CreateEmbeddingRequestArgs
pub fn model<VALUE>(&mut self, value: VALUE) -> &mut CreateEmbeddingRequestArgs
ID of the model to use. You can use the List models API to see all of your available models, or see our Model overview for descriptions of them.
Sourcepub fn input<VALUE>(&mut self, value: VALUE) -> &mut CreateEmbeddingRequestArgswhere
VALUE: Into<EmbeddingInput>,
pub fn input<VALUE>(&mut self, value: VALUE) -> &mut CreateEmbeddingRequestArgswhere
VALUE: Into<EmbeddingInput>,
Input text to embed, encoded as a string or array of tokens. To embed multiple inputs in a single request, pass an array of strings or array of token arrays. The input must not exceed the max input tokens for the model (8192 tokens for all embedding models), cannot be an empty string, and any array must be 2048 dimensions or less. Example Python code for counting tokens. In addition to the per-input token limit, all embedding models enforce a maximum of 300,000 tokens summed across all inputs in a single request.
Sourcepub fn encoding_format<VALUE>(
&mut self,
value: VALUE,
) -> &mut CreateEmbeddingRequestArgswhere
VALUE: Into<EncodingFormat>,
pub fn encoding_format<VALUE>(
&mut self,
value: VALUE,
) -> &mut CreateEmbeddingRequestArgswhere
VALUE: Into<EncodingFormat>,
The format to return the embeddings in. Can be either float or base64.
Sourcepub fn user<VALUE>(&mut self, value: VALUE) -> &mut CreateEmbeddingRequestArgs
pub fn user<VALUE>(&mut self, value: VALUE) -> &mut CreateEmbeddingRequestArgs
A unique identifier representing your end-user, which can help OpenAI to monitor and detect abuse. Learn more.
Sourcepub fn dimensions<VALUE>(
&mut self,
value: VALUE,
) -> &mut CreateEmbeddingRequestArgs
pub fn dimensions<VALUE>( &mut self, value: VALUE, ) -> &mut CreateEmbeddingRequestArgs
The number of dimensions the resulting output embeddings should have. Only supported in text-embedding-3 and later models.
Sourcepub fn build(&self) -> Result<CreateEmbeddingRequest, OpenAIError>
pub fn build(&self) -> Result<CreateEmbeddingRequest, OpenAIError>