pub struct CreateImageVariationRequestArgs { /* private fields */ }Expand description
Builder for CreateImageVariationRequest.
Implementations
Sourceimpl CreateImageVariationRequestArgs
impl CreateImageVariationRequestArgs
Sourcepub fn image<VALUE>(
&mut self,
value: VALUE,
) -> &mut CreateImageVariationRequestArgswhere
VALUE: Into<ImageInput>,
pub fn image<VALUE>(
&mut self,
value: VALUE,
) -> &mut CreateImageVariationRequestArgswhere
VALUE: Into<ImageInput>,
The image to use as the basis for the variation(s). Must be a valid PNG file, less than 4MB, and square.
Sourcepub fn model<VALUE>(
&mut self,
value: VALUE,
) -> &mut CreateImageVariationRequestArgswhere
VALUE: Into<ImageModel>,
pub fn model<VALUE>(
&mut self,
value: VALUE,
) -> &mut CreateImageVariationRequestArgswhere
VALUE: Into<ImageModel>,
The model to use for image generation. Only dall-e-2 is supported at this time.
Sourcepub fn n<VALUE>(&mut self, value: VALUE) -> &mut CreateImageVariationRequestArgs
pub fn n<VALUE>(&mut self, value: VALUE) -> &mut CreateImageVariationRequestArgs
The number of images to generate. Must be between 1 and 10.
Sourcepub fn response_format<VALUE>(
&mut self,
value: VALUE,
) -> &mut CreateImageVariationRequestArgswhere
VALUE: Into<ImageResponseFormat>,
pub fn response_format<VALUE>(
&mut self,
value: VALUE,
) -> &mut CreateImageVariationRequestArgswhere
VALUE: Into<ImageResponseFormat>,
The format in which the generated images are returned. Must be one of url or b64_json. URLs
are only valid for 60 minutes after the image has been generated.
Sourcepub fn size<VALUE>(
&mut self,
value: VALUE,
) -> &mut CreateImageVariationRequestArgswhere
VALUE: Into<DallE2ImageSize>,
pub fn size<VALUE>(
&mut self,
value: VALUE,
) -> &mut CreateImageVariationRequestArgswhere
VALUE: Into<DallE2ImageSize>,
The size of the generated images. Must be one of 256x256, 512x512, or 1024x1024.
Sourcepub fn user<VALUE>(
&mut self,
value: VALUE,
) -> &mut CreateImageVariationRequestArgs
pub fn user<VALUE>( &mut self, value: VALUE, ) -> &mut CreateImageVariationRequestArgs
A unique identifier representing your end-user, which can help OpenAI to monitor and detect abuse. Learn more.
Sourcepub fn build(&self) -> Result<CreateImageVariationRequest, OpenAIError>
pub fn build(&self) -> Result<CreateImageVariationRequest, OpenAIError>