EditImageJsonRequestArgs

Struct EditImageJsonRequestArgs 

pub struct EditImageJsonRequestArgs { /* private fields */ }
Builder for EditImageJsonRequest.

Implementations

Source

impl EditImageJsonRequestArgs

pub fn model<VALUE>(&mut self, value: VALUE) -> &mut EditImageJsonRequestArgs
where VALUE: Into<ImageModel>,

The model to use for image editing.

pub fn images<VALUE>(&mut self, value: VALUE) -> &mut EditImageJsonRequestArgs
where VALUE: Into<Vec<ImageRefParam>>,

Input image references to edit. For GPT image models, you can provide up to 16 images.

pub fn mask<VALUE>(&mut self, value: VALUE) -> &mut EditImageJsonRequestArgs
where VALUE: Into<ImageRefParam>,

An optional mask image reference indicating which areas of the image should be edited.

pub fn prompt<VALUE>(&mut self, value: VALUE) -> &mut EditImageJsonRequestArgs
where VALUE: Into<String>,

A text description of the desired image edit.

pub fn n<VALUE>(&mut self, value: VALUE) -> &mut EditImageJsonRequestArgs
where VALUE: Into<u8>,

The number of edited images to generate. Must be between 1 and 10.

pub fn quality<VALUE>(&mut self, value: VALUE) -> &mut EditImageJsonRequestArgs
where VALUE: Into<ImageQuality>,

The quality of the image that will be generated.

pub fn input_fidelity<VALUE>( &mut self, value: VALUE, ) -> &mut EditImageJsonRequestArgs
where VALUE: Into<InputFidelity>,

Control how much effort the model will exert to match the style and features, especially facial features, of input images. Supports high and low. Defaults to low.

pub fn size<VALUE>(&mut self, value: VALUE) -> &mut EditImageJsonRequestArgs
where VALUE: Into<ImageSize>,

The size of the generated image.

pub fn user<VALUE>(&mut self, value: VALUE) -> &mut EditImageJsonRequestArgs
where VALUE: Into<String>,

A unique identifier representing your end-user.

pub fn output_format<VALUE>( &mut self, value: VALUE, ) -> &mut EditImageJsonRequestArgs
where VALUE: Into<ImageOutputFormat>,

The output format for the generated image.

pub fn output_compression<VALUE>( &mut self, value: VALUE, ) -> &mut EditImageJsonRequestArgs
where VALUE: Into<u8>,

The compression level (0-100%) for the generated images.

pub fn moderation<VALUE>( &mut self, value: VALUE, ) -> &mut EditImageJsonRequestArgs
where VALUE: Into<ImageModeration>,

Control the content-moderation level for images.

pub fn background<VALUE>( &mut self, value: VALUE, ) -> &mut EditImageJsonRequestArgs
where VALUE: Into<ImageBackground>,

The background style for the generated image.

pub fn stream<VALUE>(&mut self, value: VALUE) -> &mut EditImageJsonRequestArgs
where VALUE: Into<bool>,

Whether to stream the image generation. Defaults to false.

pub fn partial_images<VALUE>( &mut self, value: VALUE, ) -> &mut EditImageJsonRequestArgs
where VALUE: Into<u8>,

The number of partial images to generate during streaming.

pub fn build(&self) -> Result<EditImageJsonRequest, OpenAIError>

Builds a new EditImageJsonRequest.

Errors

If a required field has not been initialized.