pub struct FunctionCall {
pub name: String,
pub arguments: String,
}Expand description
The name and arguments of a function that should be called.
Accepts arguments as either a JSON string ("{\"key\":\"value\"}") or a
JSON object ({"key": "value"}); both are normalised to a JSON string
on deserialisation so callers always see the canonical form.
Fields
name: Stringarguments: StringTrait Implementations
Sourceimpl Clone for FunctionCall
impl Clone for FunctionCall
Sourceimpl ComposeSchema for FunctionCall
Available on crate feature protocol-schema only.
impl ComposeSchema for FunctionCall
Available on crate feature
protocol-schema only.Sourceimpl Debug for FunctionCall
impl Debug for FunctionCall
Sourceimpl Default for FunctionCall
impl Default for FunctionCall
Sourceimpl<'de> Deserialize<'de> for FunctionCall
impl<'de> Deserialize<'de> for FunctionCall
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for FunctionCall
impl PartialEq for FunctionCall
Sourceimpl Serialize for FunctionCall
impl Serialize for FunctionCall
impl StructuralPartialEq for FunctionCall