pub struct ListFilesQuery {
pub purpose: Option<String>,
pub limit: Option<u32>,
pub order: Option<ListFilesOrder>,
pub after: Option<String>,
}Expand description
Query parameters for listing files.
Fields
purpose: Option<String>Only return files with the given purpose.
limit: Option<u32>A limit on the number of objects to be returned. Limit can range between 1 and 10,000, and the default is 10,000.
order: Option<ListFilesOrder>Sort order by the created_at timestamp of the objects. asc for ascending order and desc for descending order.
after: Option<String>A cursor for use in pagination. after is an object ID that defines your place in the list.