pub type ServiceTierResponse = ServiceTier;Expand description
Backward-compatible name for the service tier reported in responses.
Aliased Type
pub enum ServiceTierResponse {
Auto,
Default,
Flex,
Scale,
Priority,
Fast,
}pub type ServiceTierResponse = ServiceTier;Backward-compatible name for the service tier reported in responses.
pub enum ServiceTierResponse {
Auto,
Default,
Flex,
Scale,
Priority,
Fast,
}