pub struct ImageGenerationArgs { /* private fields */ }Expand description
Builder for ImageGenTool.
Implementations
Sourceimpl ImageGenerationArgs
impl ImageGenerationArgs
Sourcepub fn background<VALUE>(&mut self, value: VALUE) -> &mut ImageGenerationArgswhere
VALUE: Into<ImageGenToolBackground>,
pub fn background<VALUE>(&mut self, value: VALUE) -> &mut ImageGenerationArgswhere
VALUE: Into<ImageGenToolBackground>,
Background type for the generated image. One of transparent,
opaque, or auto. Default: auto.
Sourcepub fn input_fidelity<VALUE>(
&mut self,
value: VALUE,
) -> &mut ImageGenerationArgswhere
VALUE: Into<InputFidelity>,
pub fn input_fidelity<VALUE>(
&mut self,
value: VALUE,
) -> &mut ImageGenerationArgswhere
VALUE: Into<InputFidelity>,
Control how much effort the model will exert to match the style and features, especially facial features,
of input images. This parameter is only supported for gpt-image-1. Unsupported
for gpt-image-1-mini. Supports high and low. Defaults to low.
Sourcepub fn input_image_mask<VALUE>(
&mut self,
value: VALUE,
) -> &mut ImageGenerationArgswhere
VALUE: Into<ImageGenToolInputImageMask>,
pub fn input_image_mask<VALUE>(
&mut self,
value: VALUE,
) -> &mut ImageGenerationArgswhere
VALUE: Into<ImageGenToolInputImageMask>,
Optional mask for inpainting. Contains image_url
(string, optional) and file_id (string, optional).
Sourcepub fn model<VALUE>(&mut self, value: VALUE) -> &mut ImageGenerationArgs
pub fn model<VALUE>(&mut self, value: VALUE) -> &mut ImageGenerationArgs
The image generation model to use. Default: gpt-image-1.
Sourcepub fn moderation<VALUE>(&mut self, value: VALUE) -> &mut ImageGenerationArgswhere
VALUE: Into<ImageGenToolModeration>,
pub fn moderation<VALUE>(&mut self, value: VALUE) -> &mut ImageGenerationArgswhere
VALUE: Into<ImageGenToolModeration>,
Moderation level for the generated image. Default: auto.
Sourcepub fn output_compression<VALUE>(
&mut self,
value: VALUE,
) -> &mut ImageGenerationArgs
pub fn output_compression<VALUE>( &mut self, value: VALUE, ) -> &mut ImageGenerationArgs
Compression level for the output image. Default: 100.
Sourcepub fn output_format<VALUE>(&mut self, value: VALUE) -> &mut ImageGenerationArgswhere
VALUE: Into<ImageGenToolOutputFormat>,
pub fn output_format<VALUE>(&mut self, value: VALUE) -> &mut ImageGenerationArgswhere
VALUE: Into<ImageGenToolOutputFormat>,
The output format of the generated image. One of png, webp, or
jpeg. Default: png.
Sourcepub fn partial_images<VALUE>(
&mut self,
value: VALUE,
) -> &mut ImageGenerationArgs
pub fn partial_images<VALUE>( &mut self, value: VALUE, ) -> &mut ImageGenerationArgs
Number of partial images to generate in streaming mode, from 0 (default value) to 3.
Sourcepub fn quality<VALUE>(&mut self, value: VALUE) -> &mut ImageGenerationArgswhere
VALUE: Into<ImageGenToolQuality>,
pub fn quality<VALUE>(&mut self, value: VALUE) -> &mut ImageGenerationArgswhere
VALUE: Into<ImageGenToolQuality>,
The quality of the generated image. One of low, medium, high,
or auto. Default: auto.
Sourcepub fn size<VALUE>(&mut self, value: VALUE) -> &mut ImageGenerationArgswhere
VALUE: Into<ImageGenToolSize>,
pub fn size<VALUE>(&mut self, value: VALUE) -> &mut ImageGenerationArgswhere
VALUE: Into<ImageGenToolSize>,
The size of the generated images. For gpt-image-2 and
gpt-image-2-2026-04-21, arbitrary resolutions are supported as
WIDTHxHEIGHT strings, for example 1536x864. Width and height
must both be divisible by 16 and the requested aspect ratio must be
between 1:3 and 3:1. Resolutions above 2560x1440 are experimental,
and the maximum supported resolution is 3840x2160. The requested
size must also satisfy the model’s current pixel and edge limits.
The standard sizes 1024x1024, 1536x1024, and 1024x1536 are
supported by the GPT image models; auto is supported for models
that allow automatic sizing. For dall-e-2, use one of 256x256,
512x512, or 1024x1024. For dall-e-3, use one of 1024x1024,
1792x1024, or 1024x1792.
Sourcepub fn action<VALUE>(&mut self, value: VALUE) -> &mut ImageGenerationArgswhere
VALUE: Into<ImageGenActionEnum>,
pub fn action<VALUE>(&mut self, value: VALUE) -> &mut ImageGenerationArgswhere
VALUE: Into<ImageGenActionEnum>,
Whether to generate a new image or edit an existing image. Default: auto.
Sourcepub fn build(&self) -> Result<ImageGenTool, OpenAIError>
pub fn build(&self) -> Result<ImageGenTool, OpenAIError>