pub struct ReasoningArgs { /* private fields */ }Expand description
Builder for Reasoning.
Implementations
Sourceimpl ReasoningArgs
impl ReasoningArgs
Sourcepub fn effort<VALUE>(&mut self, value: VALUE) -> &mut ReasoningArgswhere
VALUE: Into<ReasoningEffort>,
pub fn effort<VALUE>(&mut self, value: VALUE) -> &mut ReasoningArgswhere
VALUE: Into<ReasoningEffort>,
Constrains effort on reasoning for
reasoning models.
Currently supported values are minimal, low, medium, and high. Reducing
reasoning effort can result in faster responses and fewer tokens used
on reasoning in a response.
Note: The gpt-5-pro model defaults to (and only supports) high reasoning effort.
Sourcepub fn summary<VALUE>(&mut self, value: VALUE) -> &mut ReasoningArgswhere
VALUE: Into<ReasoningSummary>,
pub fn summary<VALUE>(&mut self, value: VALUE) -> &mut ReasoningArgswhere
VALUE: Into<ReasoningSummary>,
A summary of the reasoning performed by the model. This can be
useful for debugging and understanding the model’s reasoning process.
One of auto, concise, or detailed.
concise is supported for computer-use-preview models and all reasoning models after
gpt-5.
Sourcepub fn mode<VALUE>(&mut self, value: VALUE) -> &mut ReasoningArgswhere
VALUE: Into<ReasoningModeEnum>,
pub fn mode<VALUE>(&mut self, value: VALUE) -> &mut ReasoningArgswhere
VALUE: Into<ReasoningModeEnum>,
Controls the reasoning execution mode for the request.
When returned on a response, this is the effective execution mode.
Sourcepub fn context<VALUE>(&mut self, value: VALUE) -> &mut ReasoningArgswhere
VALUE: Into<ReasoningContext>,
pub fn context<VALUE>(&mut self, value: VALUE) -> &mut ReasoningArgswhere
VALUE: Into<ReasoningContext>,
Controls which reasoning items are rendered back to the model on later turns.
If omitted or set to auto, the model determines the context mode. The
gpt-5.6 model family defaults to all_turns; earlier models default to current_turn.
When returned on a response, this is the effective reasoning context mode used for the response.