pub enum ResponseSteerInput {
Text(String),
List(Vec<ResponseSteerInputItem>),
}Expand description
Input to queue for a continuation of the response. Uses the same string or
input-item shape as response.create.input, with a non-empty array when
supplying input items.
Steering accepts only messages with the user role. Each message may
contain only type, role, and content, with content as a string or an
array of input_text, input_image, and input_file parts. The optional
type must be message. Other roles, tool outputs, and item types are not
supported for steering.
Input to queue for a continuation of the response. Uses the same string or
input-item shape as response.create.input, with a non-empty array when
supplying input items.
Steering accepts only messages with the user role. Each message may
contain only type, role, and content, with content as a string or an
array of input_text, input_image, and input_file parts. The optional
type must be message. Other roles, tool outputs, and item types are not
supported for steering.
Variants
Text(String)
List(Vec<ResponseSteerInputItem>)