pub struct EditImageJsonRequestArgs { /* private fields */ }Expand description
Builder for EditImageJsonRequest.
Implementations
Sourceimpl EditImageJsonRequestArgs
impl EditImageJsonRequestArgs
Sourcepub fn model<VALUE>(&mut self, value: VALUE) -> &mut EditImageJsonRequestArgswhere
VALUE: Into<ImageModel>,
pub fn model<VALUE>(&mut self, value: VALUE) -> &mut EditImageJsonRequestArgswhere
VALUE: Into<ImageModel>,
The model to use for image editing.
Sourcepub fn images<VALUE>(&mut self, value: VALUE) -> &mut EditImageJsonRequestArgs
pub fn images<VALUE>(&mut self, value: VALUE) -> &mut EditImageJsonRequestArgs
Input image references to edit. For GPT image models, you can provide up to 16 images.
Sourcepub fn mask<VALUE>(&mut self, value: VALUE) -> &mut EditImageJsonRequestArgswhere
VALUE: Into<ImageRefParam>,
pub fn mask<VALUE>(&mut self, value: VALUE) -> &mut EditImageJsonRequestArgswhere
VALUE: Into<ImageRefParam>,
An optional mask image reference indicating which areas of the image should be edited.
Sourcepub fn prompt<VALUE>(&mut self, value: VALUE) -> &mut EditImageJsonRequestArgs
pub fn prompt<VALUE>(&mut self, value: VALUE) -> &mut EditImageJsonRequestArgs
A text description of the desired image edit.
Sourcepub fn n<VALUE>(&mut self, value: VALUE) -> &mut EditImageJsonRequestArgs
pub fn n<VALUE>(&mut self, value: VALUE) -> &mut EditImageJsonRequestArgs
The number of edited images to generate. Must be between 1 and 10.
Sourcepub fn quality<VALUE>(&mut self, value: VALUE) -> &mut EditImageJsonRequestArgswhere
VALUE: Into<ImageQuality>,
pub fn quality<VALUE>(&mut self, value: VALUE) -> &mut EditImageJsonRequestArgswhere
VALUE: Into<ImageQuality>,
The quality of the image that will be generated.
Sourcepub fn input_fidelity<VALUE>(
&mut self,
value: VALUE,
) -> &mut EditImageJsonRequestArgswhere
VALUE: Into<InputFidelity>,
pub fn input_fidelity<VALUE>(
&mut self,
value: VALUE,
) -> &mut EditImageJsonRequestArgswhere
VALUE: Into<InputFidelity>,
Control how much effort the model will exert to match the style and features,
especially facial features, of input images. Supports high and low. Defaults to low.
Sourcepub fn size<VALUE>(&mut self, value: VALUE) -> &mut EditImageJsonRequestArgs
pub fn size<VALUE>(&mut self, value: VALUE) -> &mut EditImageJsonRequestArgs
The size of the generated image.
Sourcepub fn user<VALUE>(&mut self, value: VALUE) -> &mut EditImageJsonRequestArgs
pub fn user<VALUE>(&mut self, value: VALUE) -> &mut EditImageJsonRequestArgs
A unique identifier representing your end-user.
Sourcepub fn output_format<VALUE>(
&mut self,
value: VALUE,
) -> &mut EditImageJsonRequestArgswhere
VALUE: Into<ImageOutputFormat>,
pub fn output_format<VALUE>(
&mut self,
value: VALUE,
) -> &mut EditImageJsonRequestArgswhere
VALUE: Into<ImageOutputFormat>,
The output format for the generated image.
Sourcepub fn output_compression<VALUE>(
&mut self,
value: VALUE,
) -> &mut EditImageJsonRequestArgs
pub fn output_compression<VALUE>( &mut self, value: VALUE, ) -> &mut EditImageJsonRequestArgs
The compression level (0-100%) for the generated images.
Sourcepub fn moderation<VALUE>(
&mut self,
value: VALUE,
) -> &mut EditImageJsonRequestArgswhere
VALUE: Into<ImageModeration>,
pub fn moderation<VALUE>(
&mut self,
value: VALUE,
) -> &mut EditImageJsonRequestArgswhere
VALUE: Into<ImageModeration>,
Control the content-moderation level for images.
Sourcepub fn background<VALUE>(
&mut self,
value: VALUE,
) -> &mut EditImageJsonRequestArgswhere
VALUE: Into<ImageBackground>,
pub fn background<VALUE>(
&mut self,
value: VALUE,
) -> &mut EditImageJsonRequestArgswhere
VALUE: Into<ImageBackground>,
The background style for the generated image.
Sourcepub fn stream<VALUE>(&mut self, value: VALUE) -> &mut EditImageJsonRequestArgs
pub fn stream<VALUE>(&mut self, value: VALUE) -> &mut EditImageJsonRequestArgs
Whether to stream the image generation. Defaults to false.
Sourcepub fn partial_images<VALUE>(
&mut self,
value: VALUE,
) -> &mut EditImageJsonRequestArgs
pub fn partial_images<VALUE>( &mut self, value: VALUE, ) -> &mut EditImageJsonRequestArgs
The number of partial images to generate during streaming.
Sourcepub fn build(&self) -> Result<EditImageJsonRequest, OpenAIError>
pub fn build(&self) -> Result<EditImageJsonRequest, OpenAIError>